@@ -24,13 +24,13 @@ if ($arg =~ /Y(\d+)/) {
 }
 
 if (defined($new_x)) {
-    $F = Graphics::Framebuffer->new('FB_DEVICE' => '/dev/fb0', 'FILE_MODE' => $file, 'SHOW_ERRORS' => 1, 'SIMULATED_X' => $new_x,'SIMULATED_Y' => $new_y);
+    $F = Graphics::Framebuffer->new('FILE_MODE' => $file, 'SHOW_ERRORS' => 1, 'SIMULATED_X' => $new_x,'SIMULATED_Y' => $new_y);
 } else {
-    $F = Graphics::Framebuffer->new('FB_DEVICE' => '/dev/fb0', 'FILE_MODE' => $file, 'SHOW_ERRORS' => 1);
+    $F = Graphics::Framebuffer->new('FILE_MODE' => $file, 'SHOW_ERRORS' => 1);
 }
 
-$SIG{'QUIT'} = sub {$F->cls('ON'); exit(0);};
-$SIG{'INT'}  = sub {$F->cls('ON'); exit(0);};
+$SIG{'QUIT'} = sub {$F->clip_reset();$F->cls('ON'); exit(0);};
+$SIG{'INT'}  = sub {$F->clip_reset();$F->cls('ON'); exit(0);};
 
 my $screen_width  = $F->{'XRES'};
 my $screen_height = $F->{'YRES'};
