@@ -13,7 +13,7 @@ use Term::ANSIScreen qw(:cursor :screen :color);
 
 $| = 1;
 
-our $VERSION = 2.01;
+our $VERSION = 2.02;
 
 my $file          = 0;
 my $hold : shared = 0;
@@ -29,9 +29,16 @@ sleep 2;
 
 my @framebuffer;
 my $splash = 1;
+my $two = 1;
+$two = 2 if (-e "/dev/fb0" && -e "/dev/fb1");
+my $device = 0;
 foreach my $thr (0 .. $Threads) {
-    $framebuffer[$thr] = Graphics::Framebuffer->new('FILE_MODE' => $file, 'SPLASH' => $splash);
-    $splash = 0;
+    $framebuffer[$thr] = Graphics::Framebuffer->new('FILE_MODE' => $file, 'SPLASH' => $splash,'FB_DEVICE' => sprintf('/dev/fb%d',$device));
+    if ($two == 2) {
+		$device++;
+		$device = 0 if ($device==2);
+    }
+    $splash = 0 if ($thr >= ($two - 1));
 }
 my ($screen_width, $screen_height) = $framebuffer[0]->screen_dimensions();
 
@@ -49,12 +56,13 @@ foreach my $page (1 .. $Threads) {
         sub {
             my $Page = shift;
             my $top  = shift;
+	    my ($screen_width, $screen_height) = $framebuffer[$Page]->screen_dimensions();
             if (defined($framebuffer[$Page]->{'ERROR'})) {
                 print locate($Page, 1), clline, "ERROR: Thread $Page, $framebuffer[$Page]->{'ERROR'}" if ($screen_width > 255);
             }
             $framebuffer[$page]->clip_set({'x' => 0, 'y' => $top, 'xx' => $screen_width, 'yy' => $screen_height}) if ($screen_width > 255);
             while ($RUNNING) {
-                attract($Page);
+                attract($Page,$screen_width,$screen_height);
                 while ($hold && $RUNNING) {
                     print locate($Page, 1), clline, colored(['white on_yellow'], "Thread $Page"), ' Waiting for other threads to finish drawing before clearing screen...' if ($screen_width > 255);
                     threads->yield();
@@ -81,7 +89,9 @@ while (1) {
             sleep 1;
         }
     }
-    $framebuffer[0]->cls();
+    foreach my $c (0..$Threads) {
+	$framebuffer[$c]->cls();
+    }
 } ## end while (1)
 
 ##############################################################################
@@ -93,6 +103,8 @@ while (1) {
 
 sub attract {
     my $page   = shift;
+    my $screen_width = shift;
+    my $screen_height = shift;
     my $red    = int(rand(256));
     my $grn    = int(rand(256));
     my $blu    = int(rand(256));
